summaryrefslogtreecommitdiffstats
path: root/noatun/modules/kjofol-skin/kjtextdisplay.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'noatun/modules/kjofol-skin/kjtextdisplay.cpp')
-rw-r--r--noatun/modules/kjofol-skin/kjtextdisplay.cpp88
1 files changed, 44 insertions, 44 deletions
diff --git a/noatun/modules/kjofol-skin/kjtextdisplay.cpp b/noatun/modules/kjofol-skin/kjtextdisplay.cpp
index c1a17139..42d546a0 100644
--- a/noatun/modules/kjofol-skin/kjtextdisplay.cpp
+++ b/noatun/modules/kjofol-skin/kjtextdisplay.cpp
@@ -52,7 +52,7 @@ KJFilename::KJFilename(const TQStringList &l, KJLoader *p)
// background under filename-scroller
TQPixmap tmp = p->pixmap(p->item("backgroundimage")[1]);
mBack = new KPixmap ( TQSize(xs,ys) );
- bitBlt( mBack, 0, 0, &tmp, x, y, xs, ys, Qt::CopyROP );
+ bitBlt( mBack, 0, 0, &tmp, x, y, xs, ys, TQt::CopyROP );
setRect(x,y,xs,ys);
@@ -77,12 +77,12 @@ void KJFilename::paint(TQPainter *p, const TQRect &)
TQPixmap temp ( rect().width(), rect().height() );
// draw background into buffer
- bitBlt ( &temp, 0, 0, mBack, 0, 0, -1, -1, Qt::CopyROP );
+ bitBlt ( &temp, 0, 0, mBack, 0, 0, -1, -1, TQt::CopyROP );
// draw font into buffer
- bitBlt( &temp, 0, 0, &mView, 0, 0, rect().width(), rect().height(), Qt::CopyROP);
+ bitBlt( &temp, 0, 0, &mView, 0, 0, rect().width(), rect().height(), TQt::CopyROP);
// and draw it on screen
bitBlt(p->device(), rect().topLeft(), &temp,
- TQRect(0,0,-1,-1), Qt::CopyROP);
+ TQRect(0,0,-1,-1), TQt::CopyROP);
}
void KJFilename::timerEvent(TQTimerEvent *)
@@ -90,25 +90,25 @@ void KJFilename::timerEvent(TQTimerEvent *)
int height = mView.height();
int width = mView.width();
- TQBitmap cycleMask ( mDistance, height ); // temporary-space for moving parts of the mask
+ TQBitmap cycleMask ( mDistance, height ); // temporary-space for moving parts of the tqmask
TQPixmap cycle ( mDistance, height ); // temporary-space for moving parts of the pixmap
- TQBitmap newMask ( *mView.mask() ); // save old mask
+ TQBitmap newMask ( *mView.tqmask() ); // save old tqmask
- // copy mask like the same way we're doing it with the pixmap
- // a mask does not get copied on a bitblt automatically, we have to do
+ // copy tqmask like the same way we're doing it with the pixmap
+ // a tqmask does not get copied on a bitblt automatically, we have to do
// it "by hand"
- bitBlt(&cycleMask, 0,0, &newMask, 0,0, mDistance, height, Qt::CopyROP);
- bitBlt(&newMask, 0,0, &newMask, mDistance, 0, width-mDistance, height, Qt::CopyROP);
- bitBlt(&newMask, width-mDistance, 0, &cycleMask, 0,0, mDistance, height, Qt::CopyROP);
+ bitBlt(&cycleMask, 0,0, &newMask, 0,0, mDistance, height, TQt::CopyROP);
+ bitBlt(&newMask, 0,0, &newMask, mDistance, 0, width-mDistance, height, TQt::CopyROP);
+ bitBlt(&newMask, width-mDistance, 0, &cycleMask, 0,0, mDistance, height, TQt::CopyROP);
- bitBlt(&cycle, 0,0, &mView, 0,0, mDistance, height, Qt::CopyROP);
- bitBlt(&mView, 0,0, &mView, mDistance, 0, width-mDistance, height, Qt::CopyROP);
- bitBlt(&mView, width-mDistance, 0, &cycle, 0,0, mDistance, height, Qt::CopyROP);
+ bitBlt(&cycle, 0,0, &mView, 0,0, mDistance, height, TQt::CopyROP);
+ bitBlt(&mView, 0,0, &mView, mDistance, 0, width-mDistance, height, TQt::CopyROP);
+ bitBlt(&mView, width-mDistance, 0, &cycle, 0,0, mDistance, height, TQt::CopyROP);
- // apply the newly created mask
+ // apply the newly created tqmask
mView.setMask(newMask);
- repaint();
+ tqrepaint();
}
bool KJFilename::mousePress(const TQPoint &)
@@ -142,7 +142,7 @@ void KJFilename::readConfig()
mDistance = 1;
mTimerUpdates = KJLoader::kjofol->prefs()->titleMovingUpdates();
textFont().recalcSysFont();
- mLastTitle=""; // invalidate title so it gets repainted on next timeUpdate()
+ mLastTitle=""; // tqinvalidate title so it gets tqrepainted on next timeUpdate()
}
void KJFilename::prepareString(const TQCString &str)
@@ -167,7 +167,7 @@ void KJFilename::timeUpdate(int)
mLastTitle = title;
TQCString timestring = napp->player()->lengthString().local8Bit();
- timestring = timestring.mid(timestring.find('/')+1);
+ timestring = timestring.mid(timestring.tqfind('/')+1);
prepareString ( title + " (" + timestring + ") ");
}
@@ -206,7 +206,7 @@ KJTime::KJTime(const TQStringList &l, KJLoader *p)
// background under time-display
TQPixmap tmp = p->pixmap(p->item("backgroundimage")[1]);
mBack = new KPixmap ( TQSize(xs,ys) );
- bitBlt( mBack, 0, 0, &tmp, x, y, xs, ys, Qt::CopyROP );
+ bitBlt( mBack, 0, 0, &tmp, x, y, xs, ys, TQt::CopyROP );
setRect(x,y,xs,ys);
@@ -226,13 +226,13 @@ void KJTime::paint(TQPainter *p, const TQRect &)
TQPixmap temp ( rect().width(), rect().height() );
// draw background into buffer
- bitBlt ( &temp, 0, 0, mBack, 0, 0, -1, -1, Qt::CopyROP );
- // draw time-display into buffer (that's a pixmap with a mask applied)
- bitBlt( &temp, 0, 0, &mTime, 0, 0, rect().width(), rect().height(), Qt::CopyROP);
+ bitBlt ( &temp, 0, 0, mBack, 0, 0, -1, -1, TQt::CopyROP );
+ // draw time-display into buffer (that's a pixmap with a tqmask applied)
+ bitBlt( &temp, 0, 0, &mTime, 0, 0, rect().width(), rect().height(), TQt::CopyROP);
// and draw it on screen
bitBlt(p->device(), rect().topLeft(), &temp,
- TQRect(0,0, rect().width(), rect().height()), Qt::CopyROP);
+ TQRect(0,0, rect().width(), rect().height()), TQt::CopyROP);
}
bool KJTime::mousePress(const TQPoint &)
@@ -255,7 +255,7 @@ void KJTime::readConfig()
// kdDebug(66666) << "KJTime::readConfig()" << endl;
countDown = napp->displayRemaining();
timeFont().recalcSysFont();
- mLastTime=""; // invalidate time so it gets repainted on next timeUpdate()
+ mLastTime=""; // tqinvalidate time so it gets tqrepainted on next timeUpdate()
}
TQString KJTime::lengthString ( void )
@@ -325,7 +325,7 @@ void KJTime::prepareString(const TQCString &str)
mLastTime = str;
mTime = timeFont().draw(str, rect().width());
- repaint();
+ tqrepaint();
// kdDebug(66666) << "END KJTime::prepareString(const TQCString &str)" << endl;
}
@@ -364,7 +364,7 @@ KJVolumeText::KJVolumeText(const TQStringList &l, KJLoader *p)
// background under volumetext-display
TQPixmap tmp = p->pixmap(p->item("backgroundimage")[1]);
mBack = new KPixmap ( TQSize(xs,ys) );
- bitBlt( mBack, 0, 0, &tmp, x, y, xs, ys, Qt::CopyROP );
+ bitBlt( mBack, 0, 0, &tmp, x, y, xs, ys, TQt::CopyROP );
setRect(x,y,xs,ys);
@@ -381,13 +381,13 @@ void KJVolumeText::paint(TQPainter *p, const TQRect &)
TQPixmap temp ( rect().width(), rect().height() );
// draw background into buffer
- bitBlt ( &temp, 0, 0, mBack, 0, 0, -1, -1, Qt::CopyROP );
+ bitBlt ( &temp, 0, 0, mBack, 0, 0, -1, -1, TQt::CopyROP );
// draw time-display into buffer
- bitBlt( &temp, 0, 0, &mVolume, 0, 0, rect().width(), rect().height(), Qt::CopyROP);
+ bitBlt( &temp, 0, 0, &mVolume, 0, 0, rect().width(), rect().height(), TQt::CopyROP);
// and draw it on screen
bitBlt(p->device(), rect().topLeft(), &temp,
- TQRect(0,0,-1,-1), Qt::CopyROP);
+ TQRect(0,0,-1,-1), TQt::CopyROP);
}
bool KJVolumeText::mousePress(const TQPoint &)
@@ -398,7 +398,7 @@ bool KJVolumeText::mousePress(const TQPoint &)
void KJVolumeText::readConfig()
{
volumeFont().recalcSysFont();
- mLastVolume=""; // invalidate value so it gets repainted on next timeUpdate()
+ mLastVolume=""; // tqinvalidate value so it gets tqrepainted on next timeUpdate()
}
void KJVolumeText::timeUpdate(int)
@@ -421,7 +421,7 @@ void KJVolumeText::prepareString(const TQCString &str)
mLastVolume = str;
mVolume = volumeFont().draw(str, rect().width());
- repaint();
+ tqrepaint();
}
TQString KJVolumeText::tip()
@@ -454,7 +454,7 @@ KJPitchText::KJPitchText(const TQStringList &l, KJLoader *p)
// background under time-display
TQPixmap tmp = p->pixmap(p->item("backgroundimage")[1]);
mBack = new KPixmap ( TQSize(xs,ys) );
- bitBlt( mBack, 0, 0, &tmp, x, y, xs, ys, Qt::CopyROP );
+ bitBlt( mBack, 0, 0, &tmp, x, y, xs, ys, TQt::CopyROP );
setRect(x,y,xs,ys);
@@ -472,11 +472,11 @@ void KJPitchText::paint(TQPainter *p, const TQRect &)
TQPixmap temp ( rect().width(), rect().height() );
// draw background into buffer
- bitBlt ( &temp, 0, 0, mBack, 0, 0, -1, -1, Qt::CopyROP );
+ bitBlt ( &temp, 0, 0, mBack, 0, 0, -1, -1, TQt::CopyROP );
// draw time-display into buffer
- bitBlt( &temp, 0, 0, &mSpeed, 0, 0, rect().width(), rect().height(), Qt::CopyROP);
+ bitBlt( &temp, 0, 0, &mSpeed, 0, 0, rect().width(), rect().height(), TQt::CopyROP);
// and draw it on screen
- bitBlt(p->device(), rect().topLeft(), &temp, TQRect(0,0,-1,-1), Qt::CopyROP);
+ bitBlt(p->device(), rect().topLeft(), &temp, TQRect(0,0,-1,-1), TQt::CopyROP);
}
bool KJPitchText::mousePress(const TQPoint &)
@@ -501,7 +501,7 @@ void KJPitchText::mouseRelease(const TQPoint &, bool in)
void KJPitchText::readConfig()
{
pitchFont().recalcSysFont();
- mLastPitch=""; // invalidate value so it gets repainted on next timeUpdate()
+ mLastPitch=""; // tqinvalidate value so it gets tqrepainted on next timeUpdate()
}
void KJPitchText::timeUpdate(int)
@@ -529,7 +529,7 @@ void KJPitchText::prepareString(const TQCString &str)
mLastPitch = str;
mSpeed = pitchFont().draw(str, rect().width());
- repaint();
+ tqrepaint();
}
TQString KJPitchText::tip()
@@ -566,7 +566,7 @@ KJFileInfo::KJFileInfo(const TQStringList &l, KJLoader *p)
// background under info-display
TQPixmap tmp = p->pixmap(p->item("backgroundimage")[1]);
mBack = new KPixmap ( TQSize(xs,ys) );
- bitBlt( mBack, 0, 0, &tmp, x, y, xs, ys, Qt::CopyROP );
+ bitBlt( mBack, 0, 0, &tmp, x, y, xs, ys, TQt::CopyROP );
setRect(x,y,xs,ys);
@@ -583,13 +583,13 @@ void KJFileInfo::paint(TQPainter *p, const TQRect &)
TQPixmap temp ( rect().width(), rect().height() );
// draw background into buffer
- bitBlt ( &temp, 0, 0, mBack, 0, 0, -1, -1, Qt::CopyROP );
- // draw time-display into buffer (that's a pixmap with a mask applied)
- bitBlt( &temp, 0, 0, &mTime, 0, 0, rect().width(), rect().height(), Qt::CopyROP);
+ bitBlt ( &temp, 0, 0, mBack, 0, 0, -1, -1, TQt::CopyROP );
+ // draw time-display into buffer (that's a pixmap with a tqmask applied)
+ bitBlt( &temp, 0, 0, &mTime, 0, 0, rect().width(), rect().height(), TQt::CopyROP);
// and draw it on screen
bitBlt(p->device(), rect().topLeft(), &temp,
- TQRect(0,0, rect().width(), rect().height()), Qt::CopyROP);
+ TQRect(0,0, rect().width(), rect().height()), TQt::CopyROP);
}
bool KJFileInfo::mousePress(const TQPoint &)
@@ -600,7 +600,7 @@ bool KJFileInfo::mousePress(const TQPoint &)
void KJFileInfo::readConfig()
{
textFont().recalcSysFont();
- mLastTime=""; // invalidate value so it gets repainted on next timeUpdate()
+ mLastTime=""; // tqinvalidate value so it gets tqrepainted on next timeUpdate()
}
void KJFileInfo::timeUpdate(int)
@@ -634,7 +634,7 @@ void KJFileInfo::prepareString(const TQCString &str)
return;
mLastTime = str;
mTime = textFont().draw(str, rect().width());
- repaint();
+ tqrepaint();
}
TQString KJFileInfo::tip()